@@ -55,7 +55,7 @@ void StatPopup::Reading::Init(int which, StatPopup* popup)
     color = popup->defaultDockColor(which);
     color = popup->config->readColorEntry(colorid, &color);
     actColor = new TDEAction(i18n("Color (%1)...").arg(popup->dockName(which)),
-        "color", 0, TQT_TQOBJECT(popup), TQT_SLOT(selectColor()), popup->coll, colorid);
+        "color", 0, popup, TQ_SLOT(selectColor()), popup->coll, colorid);
 }
 
 
@@ -84,7 +84,7 @@ StatPopup::StatPopup(bool useSupportSplit, TQWidget *parent, const char *name) :
 
     // Set up a timer for our periodic updates.
     timer = new TQTimer(this);
-    connect(timer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(takeReading()));
+    connect(timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(takeReading()));
 }
 
 StatPopup::~StatPopup() {
@@ -334,51 +334,51 @@ void StatPopup::setupActions() {
     bVal = config->readBoolEntry("Active", true);
     actActive = new TDEToggleAction(i18n("&Active"), 0, coll, "active");
     actActive->setChecked(bVal);
-    connect(actActive, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(setActive(bool)));
+    connect(actActive, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(setActive(bool)));
 
     actClearHistory = new TDEAction(i18n("&Clear"), "edit-delete", 0,
-        TQT_TQOBJECT(this), TQT_SLOT(clearHistory()), coll, "clear");
+        this, TQ_SLOT(clearHistory()), coll, "clear");
 
     speed = config->readNumEntry("Speed", DEFAULT_SPEED);
     actSpeed = new TDEAction(i18n("&Speed..."), "speedarrow", 0,
-        TQT_TQOBJECT(this), TQT_SLOT(selectSpeed()), coll, "speed");
+        this, TQ_SLOT(selectSpeed()), coll, "speed");
 
     if (supportSplit) {
         bVal = config->readBoolEntry("Split", true);
         actSplit = new IconToggleAction(i18n("Sp&lit Graph"), "split",
             i18n("Graph Sp&litting Enabled"), "spliton", 0, coll, "split");
         actSplit->setChecked(bVal);
-        connect(actSplit, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(setSplit(bool)));
+        connect(actSplit, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(setSplit(bool)));
     }
 
     fillStyle = config->readNumEntry("StyleID", StatDock::fillShaded);
     actFillLines = new IconToggleAction(i18n("&Lines"), "lines", "lineson", 0,
-        TQT_TQOBJECT(this), TQT_SLOT(setFillLines()), coll, "filllines");
+        this, TQ_SLOT(setFillLines()), coll, "filllines");
     actFillLines->setChecked(fillStyle == StatDock::fillLines);
     actFillBars = new IconToggleAction(i18n("&Bars"), "bars", "barson", 0,
-        TQT_TQOBJECT(this), TQT_SLOT(setFillBars()), coll, "fillbars");
+        this, TQ_SLOT(setFillBars()), coll, "fillbars");
     actFillBars->setChecked(fillStyle == StatDock::fillBars);
     actFillShaded = new IconToggleAction(i18n("&Shaded"), "shaded", "shadedon",
-        0, TQT_TQOBJECT(this), TQT_SLOT(setFillShaded()), coll, "fillshaded");
+        0, this, TQ_SLOT(setFillShaded()), coll, "fillshaded");
     actFillShaded->setChecked(fillStyle == StatDock::fillShaded);
 
     bVal = config->readBoolEntry("Soft", false);
     actSoft = new IconToggleAction(i18n("So&ft Curves"), "soft",
         i18n("So&ft Curves Enabled"), "softon", 0, coll, "soft");
     actSoft->setChecked(bVal);
-    connect(actSoft, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(setSoft(bool)));
+    connect(actSoft, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(setSoft(bool)));
 
     bVal = config->readBoolEntry("Labelled", true);
     actLabelled= new IconToggleAction(i18n("Show &Labels"), "labels",
         i18n("&Labels Enabled"), "labelson", 0, coll, "labelled");
     actLabelled->setChecked(bVal);
-    connect(actLabelled, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(setLabelled(bool)));
+    connect(actLabelled, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(setLabelled(bool)));
 
     bVal = config->readBoolEntry("Grid", true);
     actGrid = new IconToggleAction(i18n("Show &Grid"), "grid",
         i18n("&Grid Enabled"), "gridon", 0, coll, "grid");
     actGrid->setChecked(bVal);
-    connect(actGrid, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(setGrid(bool)));
+    connect(actGrid, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(setGrid(bool)));
 
     setupCustomActions();
 }
@@ -404,7 +404,7 @@ void StatPopup::paintEvent(TQPaintEvent*) {
 }
 
 void StatPopup::mousePressEvent(TQMouseEvent* e) {
-    if(e->button() == Qt::RightButton) {
+    if(e->button() == TQt::RightButton) {
         // Hide the pop-up.
         hide();
     } else {
